Updating xml takes more than usual
Monday, 20 April 2015 · 2 messages
GK
George Karakatsiotis20 Apr 2015 09:58 #
Hi all,
I have deployed basex.war (8.0.3) in a resin web server (with default options) and sometimes updating takes longer than usual. Here is a snippet from .logs:
1 resource(s) replaced in 2323.41 ms. 423273.55 ms
My understanding is that updating takes 2323.41 ms, but overall the whole process takes 423273.55 ms. Do you have any suggestion what could be the cause of these delays? I should note that this happens while processing a big batch of documents in parallel (each HTTP request is in a different thread).
Thank you for your time,
GK
ML
Marco Lettere20 Apr 2015 10:18 #
Hi George,
we had a similar issue in a very update intensive scenario.
The bottleneck is most probably disk access in highly concurrent contexts. Serializing access is performing much better because it reduces HD access time.
Thus either use one thread only for posting your updates or set PARALELL=1 in the .basex file.
The latter option will sequentialize the access to the DB.
Hope this helps,
Marco.
Quoted text · George Karakatsiotis · 15 lines
On 20/04/2015 09:58, George Karakatsiotis wrote: > Hi all, > I have deployed basex.war (8.0.3) in a resin web server (with default > options) and sometimes updating takes longer than usual. Here is a > snippet from .logs: > 1 resource(s) replaced in 2323.41 ms. 423273.55 ms > > My understanding is that updating takes 2323.41 ms, but overall the > whole process takes 423273.55 ms. Do you have any suggestion what > could be the cause of these delays? I should note that this happens > while processing a big batch of documents in parallel (each HTTP > request is in a different thread). > > Thank you for your time, > GK
Written for BaseX 8.1. BaseX may have changed since: please check the current documentation.
⚡Generated with XQuery